==> extranet-property-sdk-java-30.3.1-sources.jar: travel/wink/sdk/extranet/property/api/GeoLocationApi.java <==
package travel.wink.sdk.extranet.property.api;

import travel.wink.sdk.extranet.property.invoker.ApiClient;

import travel.wink.sdk.extranet.property.model.GenericErrorMessage;
import travel.wink.sdk.extranet.property.model.HotelViewSupplier;
import travel.wink.sdk.extranet.property.model.ShowPropertyPolicy400Response;
import travel.wink.sdk.extranet.property.model.UpdateLocationRequestSupplier;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.web.reactive.function.client.WebClient.ResponseSpec;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import reactor.core.publisher.Mono;
import reactor.core.publisher.Flux;

@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-08-12T10:04:02.243083328+07:00[Asia/Bangkok]")
public class GeoLocationApi {
    private ApiClient apiClient;

    public GeoLocationApi() {
        this(new ApiClient());
    }

    @Autowired
    public GeoLocationApi(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return apiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return HotelViewSupplier
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec updateGeoLocationRequestCreation(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        Object postBody = updateLocationRequestSupplier;
        // verify the required parameter 'propertyIdentifier' is set
        if (propertyIdentifier == null) {
            throw new WebClientResponseException("Missing the required parameter 'propertyIdentifier' when calling updateGeoLocation", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // verify the required parameter 'updateLocationRequestSupplier' is set
        if (updateLocationRequestSupplier == null) {
            throw new WebClientResponseException("Missing the required parameter 'updateLocationRequestSupplier' when calling updateGeoLocation", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        pathParams.put("propertyIdentifier", propertyIdentifier);

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        if (winkVersion != null)
        headerParams.add("Wink-Version", apiClient.parameterToString(winkVersion));
        final String[] localVarAccepts = { 
            "application/json", "application/xml", "text/xml", "text/plain", "*/*"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2ClientCredentials" };

        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return apiClient.invokeAPI("/api/property/{propertyIdentifier}/location", HttpMethod.PATCH, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return HotelViewSupplier
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<HotelViewSupplier> updateGeoLocation(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion).bodyToMono(localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return ResponseEntity&lt;HotelViewSupplier&gt;
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<ResponseEntity<HotelViewSupplier>> updateGeoLocationWithHttpInfo(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion).toEntity(localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return ResponseSpec
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public ResponseSpec updateGeoLocationWithResponseSpec(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion);
    }
}

==> extranet-property-sdk-java-30.4.1-sources.jar: travel/wink/sdk/extranet/property/api/GeoLocationApi.java <==
package travel.wink.sdk.extranet.property.api;

import travel.wink.sdk.extranet.property.invoker.ApiClient;

import travel.wink.sdk.extranet.property.model.GenericErrorMessage;
import travel.wink.sdk.extranet.property.model.HotelViewSupplier;
import travel.wink.sdk.extranet.property.model.ShowRecognition400Response;
import travel.wink.sdk.extranet.property.model.UpdateLocationRequestSupplier;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.core.ParameterizedTypeReference;
import org.springframework.web.reactive.function.client.WebClient.ResponseSpec;
import org.springframework.web.reactive.function.client.WebClientResponseException;
import org.springframework.core.io.FileSystemResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import reactor.core.publisher.Mono;
import reactor.core.publisher.Flux;

@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-08-12T22:11:51.081450123+07:00[Asia/Bangkok]")
public class GeoLocationApi {
    private ApiClient apiClient;

    public GeoLocationApi() {
        this(new ApiClient());
    }

    @Autowired
    public GeoLocationApi(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    public ApiClient getApiClient() {
        return apiClient;
    }

    public void setApiClient(ApiClient apiClient) {
        this.apiClient = apiClient;
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return HotelViewSupplier
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    private ResponseSpec updateGeoLocationRequestCreation(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        Object postBody = updateLocationRequestSupplier;
        // verify the required parameter 'propertyIdentifier' is set
        if (propertyIdentifier == null) {
            throw new WebClientResponseException("Missing the required parameter 'propertyIdentifier' when calling updateGeoLocation", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // verify the required parameter 'updateLocationRequestSupplier' is set
        if (updateLocationRequestSupplier == null) {
            throw new WebClientResponseException("Missing the required parameter 'updateLocationRequestSupplier' when calling updateGeoLocation", HttpStatus.BAD_REQUEST.value(), HttpStatus.BAD_REQUEST.getReasonPhrase(), null, null, null);
        }
        // create path and map variables
        final Map<String, Object> pathParams = new HashMap<String, Object>();

        pathParams.put("propertyIdentifier", propertyIdentifier);

        final MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<String, String>();
        final HttpHeaders headerParams = new HttpHeaders();
        final MultiValueMap<String, String> cookieParams = new LinkedMultiValueMap<String, String>();
        final MultiValueMap<String, Object> formParams = new LinkedMultiValueMap<String, Object>();

        if (winkVersion != null)
        headerParams.add("Wink-Version", apiClient.parameterToString(winkVersion));
        final String[] localVarAccepts = { 
            "application/json", "application/xml", "text/xml", "text/plain", "*/*"
        };
        final List<MediaType> localVarAccept = apiClient.selectHeaderAccept(localVarAccepts);
        final String[] localVarContentTypes = { 
            "application/json"
        };
        final MediaType localVarContentType = apiClient.selectHeaderContentType(localVarContentTypes);

        String[] localVarAuthNames = new String[] { "oauth2ClientCredentials" };

        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return apiClient.invokeAPI("/api/property/{propertyIdentifier}/location", HttpMethod.PATCH, pathParams, queryParams, postBody, headerParams, cookieParams, formParams, localVarAccept, localVarContentType, localVarAuthNames, localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return HotelViewSupplier
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<HotelViewSupplier> updateGeoLocation(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion).bodyToMono(localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return ResponseEntity&lt;HotelViewSupplier&gt;
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public Mono<ResponseEntity<HotelViewSupplier>> updateGeoLocationWithHttpInfo(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        ParameterizedTypeReference<HotelViewSupplier> localVarReturnType = new ParameterizedTypeReference<HotelViewSupplier>() {};
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion).toEntity(localVarReturnType);
    }

    /**
     * Set Geo-Location
     * Update property geo-location. Note: x &#x3D; longitude, y &#x3D; latitude, type &#x3D; Point, coordinates &#x3D; [longitude, latitude].
     * <p><b>500</b> - Internal Server Error
     * <p><b>403</b> - Forbidden
     * <p><b>401</b> - Unauthorized
     * <p><b>400</b> - Bad Request
     * <p><b>200</b> - OK
     * @param propertyIdentifier Update geo-location for this property identifier
     * @param updateLocationRequestSupplier Update geo-location request body
     * @param winkVersion The winkVersion parameter
     * @return ResponseSpec
     * @throws WebClientResponseException if an error occurs while attempting to invoke the API
     */
    public ResponseSpec updateGeoLocationWithResponseSpec(String propertyIdentifier, UpdateLocationRequestSupplier updateLocationRequestSupplier, String winkVersion) throws WebClientResponseException {
        return updateGeoLocationRequestCreation(propertyIdentifier, updateLocationRequestSupplier, winkVersion);
    }
}
